==> apigateway-0.33.0-sources.jar: software/amazon/awscdk/services/apigateway/ApiKeyAttributes.java <==
package software.amazon.awscdk.services.apigateway;

/**
 * API keys are alphanumeric string values that you distribute to app developer customers to grant access to your API.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.11.0 (build 3d6415e)", date = "2019-05-30T15:06:14.358Z")
public interface ApiKeyAttributes extends software.amazon.jsii.JsiiSerializable {
    /**
     * The API key ID.
     */
    java.lang.String getKeyId();

    /**
     * @return a {@link Builder} of {@link ApiKeyAttributes}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link ApiKeyAttributes}
     */
    final class Builder {
        private java.lang.String _keyId;

        /**
         * Sets the value of KeyId
         * @param value The API key ID.
         * @return {@code this}
         */
        public Builder withKeyId(final java.lang.String value) {
            this._keyId = java.util.Objects.requireNonNull(value, "keyId is required");
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ApiKeyAttributes}
         * @throws NullPointerException if any required attribute was not provided
         */
        public ApiKeyAttributes build() {
            return new ApiKeyAttributes() {
                private final java.lang.String $keyId = java.util.Objects.requireNonNull(_keyId, "keyId is required");

                @Override
                public java.lang.String getKeyId() {
                    return this.$keyId;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    obj.set("keyId", om.valueToTree(this.getKeyId()));
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.apigateway.ApiKeyAttributes {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * The API key ID.
         */
        @Override
        public java.lang.String getKeyId() {
            return this.jsiiGet("keyId", java.lang.String.class);
        }
    }
}

==> apigateway-0.34.0-sources.jar: software/amazon/awscdk/services/apigateway/ApiKeyAttributes.java <==
package software.amazon.awscdk.services.apigateway;

/**
 * API keys are alphanumeric string values that you distribute to app developer customers to grant access to your API.
 * 
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.11.2 (build 27d16c2)", date = "2019-06-10T11:12:46.454Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface ApiKeyAttributes extends software.amazon.jsii.JsiiSerializable {
    /**
     * The API key ID.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.String getKeyId();

    /**
     * @return a {@link Builder} of {@link ApiKeyAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link ApiKeyAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    final class Builder {
        private java.lang.String _keyId;

        /**
         * Sets the value of KeyId
         * @param value The API key ID.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder withKeyId(final java.lang.String value) {
            this._keyId = java.util.Objects.requireNonNull(value, "keyId is required");
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ApiKeyAttributes}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public ApiKeyAttributes build() {
            return new ApiKeyAttributes() {
                private final java.lang.String $keyId = java.util.Objects.requireNonNull(_keyId, "keyId is required");

                @Override
                public java.lang.String getKeyId() {
                    return this.$keyId;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    obj.set("keyId", om.valueToTree(this.getKeyId()));
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.apigateway.ApiKeyAttributes {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * The API key ID.
         * 
         * EXPERIMENTAL
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public java.lang.String getKeyId() {
            return this.jsiiGet("keyId", java.lang.String.class);
        }
    }
}
